@@ -3,6 +3,5 @@ Bootstrap styling module for ReactPy.
 """
 
 from .Configuration import configure as configure_boots, default_css as default_boots
-from .generate import Convert_style as convert_imports_to_link
 
-__all__ = ['configure_boots', 'default_boots', 'convert_imports_to_link']
\ No newline at end of file
+__all__ = ['configure_boots', 'default_boots']
\ No newline at end of file
